==> haskell-hls-explicit-fixity-plugin-2.1.0.0-63-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-explicit-fixity-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-explicit-fixity-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-explicit-fixity-plugin-2.1.0.0-5PkGUonp5MXGzpUqcsnrnY
key:                  hls-explicit-fixity-plugin-2.1.0.0-5PkGUonp5MXGzpUqcsnrnY
license:              Apache-2.0
maintainer:           julytreee@gmail.com
author:               Lei Zhu
synopsis:             Show fixity explicitly while hovering
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/plugins/hls-explicit-fixity-plugin#readme>

category:             Development
abi:                  981386640caccb5087d2b071c513ad5c
exposed:              True
exposed-modules:      Ide.Plugin.ExplicitFixity
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-fixity-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-fixity-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-fixity-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-explicit-fixity-plugin
hs-libraries:         HShls-explicit-fixity-plugin-2.1.0.0-5PkGUonp5MXGzpUqcsnrnY
depends:
    base-4.17.2.1 containers-0.6.7 deepseq-1.4.8.0
    extra-1.7.16-Bd5z33Uz6vY4Zv52jbXbiv ghc-9.4.8
    ghcide-2.1.0.0-DV1whINEKVtDomh5tIvVTq
    hashable-1.4.5.0-JHGJZlFhSc53NK2NYV614f
    hls-plugin-api-2.1.0.0-a5PLiUbwfYLestaynbTX7
    lsp-2.1.0.0-LxSKkJdBj4g1eg9hTKXJFR text-2.0.2 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-explicit-fixity-plugin/html/hls-explicit-fixity-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-explicit-fixity-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-explicit-fixity-plugin-2.1.0.0-64-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-explicit-fixity-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-explicit-fixity-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-explicit-fixity-plugin-2.1.0.0-8ZIUvGE7Q1lAPGxz7J03aJ
key:                  hls-explicit-fixity-plugin-2.1.0.0-8ZIUvGE7Q1lAPGxz7J03aJ
license:              Apache-2.0
maintainer:           julytreee@gmail.com
author:               Lei Zhu
synopsis:             Show fixity explicitly while hovering
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/plugins/hls-explicit-fixity-plugin#readme>

category:             Development
abi:                  0c57ea344805dba3e035ac27a504311a
exposed:              True
exposed-modules:      Ide.Plugin.ExplicitFixity
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-fixity-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-fixity-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-fixity-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-explicit-fixity-plugin
hs-libraries:         HShls-explicit-fixity-plugin-2.1.0.0-8ZIUvGE7Q1lAPGxz7J03aJ
depends:
    base-4.17.2.1 containers-0.6.7 deepseq-1.4.8.0
    extra-1.7.16-KGJm7HE8TMo8c4jTE4Z3yy ghc-9.4.8
    ghcide-2.1.0.0-HkHChJygH7CLJmn9bJ7b42
    hashable-1.4.5.0-EMf4Iv4OllUGRj72K4SCf0
    hls-plugin-api-2.1.0.0-5KDvY2JKxHoHPQnj9L04aj
    lsp-2.1.0.0-JxmIZMl2v9k6LfbUc7lPpP text-2.0.2 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-explicit-fixity-plugin/html/hls-explicit-fixity-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-explicit-fixity-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
